modarea: Moderation Area: An Effect Size for Interactions

Description Usage Arguments Details Value Note Author(s) References See Also Examples

View source: R/modarea.R

Description

Moderation Area is used to quantify the effect size of interactions in moderated multiple regression. It calculates the area between simple slopes lines at set low and high SDs, and standardizes the value given theoretical space.

Usage

1
modarea(x, y, m, xSD, mSD, K)

Arguments

x

predictor

y

outcome

m

moderator

xSD

low and high SDs of the predictor to test

mSD

low and high SDs of the moderator to test

K

number of bootstrap iterations

Details

No additional details.

Value

0 to infinity

Note

No further notes.

Author(s)

Shane J. Sacco, M.A. University of Connecticut

References

No references

See Also

no other links to see.

Examples

1
2
3
4
5
6
x1 = rnorm(1000,0,1)
m1 = rnorm(1000,0,1)
e1 = rnorm(1000,0,1)
y1 = x1 + m1 + x1*m1 + e1

modarea(x1, y1, m1, 1, 1, 10000)

saccosj/modarea documentation built on Nov. 5, 2019, 5:11 a.m.