Description Usage Arguments Details Value Note Author(s) References See Also Examples
Moderation Area is used to quantify the effect size of interactions in moderated multiple regression. It calculates the area between simple slopes lines at set low and high SDs, and standardizes the value given theoretical space.
1 | modarea(x, y, m, xSD, mSD, K)
|
x |
predictor |
y |
outcome |
m |
moderator |
xSD |
low and high SDs of the predictor to test |
mSD |
low and high SDs of the moderator to test |
K |
number of bootstrap iterations |
No additional details.
0 to infinity
No further notes.
Shane J. Sacco, M.A. University of Connecticut
No references
no other links to see.
1 2 3 4 5 6 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.